package edu.mermet.tp8;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Properties;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JDesktopPane;
import javax.swing.JFrame;
import javax.swing.JInternalFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;

import edu.mermet.tp8.fenetres.FenetreBoutons;
import edu.mermet.tp8.fenetres.FenetreConversion;
import edu.mermet.tp8.fenetres.FenetreDiaporama;
import edu.mermet.tp8.fenetres.FenetreSuggestion;
import edu.mermet.tp8.fenetres.FenetreTexte;
import edu.mermet.tp8.actions.ActionAfficherCommentFaire;
import edu.mermet.tp8.actions.ActionAfficherConfigurationMenu;

/**
 *
 * @author brunomermet
 */
public class Application extends JFrame {
    private JInternalFrame conversion;
    private JInternalFrame texte;
    private JInternalFrame diaporama;
    private JInternalFrame boutons;
    private Action actionAfficherConversion;
    private Action actionAfficherTexte;
    private Action actionAfficherDiaporama;
    private Action actionAfficherBoutons;
    private Action actionAfficherCommentFaire;
    private Action actionAfficherConfigurationMenu;

    public Application() {
        super("multi-fenêtres");
        this.setContentPane(new JDesktopPane());

        // ****** Barre de menu ******
        JMenuBar barre = new JMenuBar();
        // ------ menu Fichier ------
        JMenu menuFichier = new JMenu("Fichier");
        menuFichier.setMnemonic(KeyEvent.VK_F);
        JMenuItem quitter = new JMenuItem("Quitter");
        quitter.addActionListener (new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent aev) {
                System.exit(0);
            }
        });
        quitter.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Q, InputEvent.CTRL_DOWN_MASK));
        menuFichier.add(quitter);
        barre.add(menuFichier);
        this.setJMenuBar(barre);
        // ------ menu Applications ------
        JMenu menuApplication = new JMenu("Applications");
        menuApplication.setMnemonic(KeyEvent.VK_A);
        actionAfficherConversion = new ActionAfficherConversion();
        JMenuItem itemConversion = new JMenuItem(actionAfficherConversion);
        menuApplication.add(itemConversion);
        actionAfficherTexte = new ActionAfficherTexte();
        JMenuItem itemTexte = new JMenuItem(actionAfficherTexte);
        menuApplication.add(itemTexte);
        actionAfficherDiaporama = new ActionAfficherDiaporama();
        JMenuItem itemDiaporama = new JMenuItem(actionAfficherDiaporama);
        menuApplication.add(itemDiaporama);
        actionAfficherBoutons = new ActionAfficherBoutons();
        JMenuItem itemBoutons = new JMenuItem(actionAfficherBoutons);
        menuApplication.add(itemBoutons);
        barre.add(menuApplication);
        // ------ menu Aide ------
        JMenu menuAide = new JMenu("Aide");
        menuAide.setMnemonic(KeyEvent.VK_H);
        actionAfficherCommentFaire = new ActionAfficherCommentFaire(this);
        JMenuItem itemCommentFaire = new JMenuItem(actionAfficherCommentFaire);
        menuAide.add(itemCommentFaire);
        actionAfficherConfigurationMenu = new ActionAfficherConfigurationMenu(this);
        JMenuItem itemConfigurationMenu = new JMenuItem(actionAfficherConfigurationMenu);
        menuAide.add(itemConfigurationMenu);
        barre.add(menuAide);
        // ****** Fin barre de menu ******
        
        // ****** Création des fenêtres ******
        // ------ fenêtre conversion ------
        conversion = new FenetreConversion(actionAfficherConversion);
        this.add(conversion);
        // ------ fenêtre texte ------
        texte = new FenetreTexte(actionAfficherTexte);
        this.add(texte);
        // ------ fenêtre diaporama ------
        diaporama = new FenetreDiaporama(actionAfficherDiaporama);
        this.add(diaporama);
        // ------ fenêtre boutons ------
        boutons = new FenetreBoutons(this,actionAfficherBoutons);
        this.add(boutons);
        // ****** Fin création fenêtres ******

        FenetreSuggestion suggestions = new FenetreSuggestion();
        this.add(suggestions);
        
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setSize(600,300);
        this.setLocationRelativeTo(null);
        setVisible(true);
    }

    private class ActionAfficherBoutons extends AbstractAction {
        public ActionAfficherBoutons() {
            super("Boutons");
            putValue(Action.ACCELERATOR_KEY,KeyStroke.getKeyStroke(KeyEvent.VK_B, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY,KeyEvent.VK_B);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            boutons.setVisible(true);
            enableBoutons(false);
        }
    }

    private class ActionAfficherDiaporama extends AbstractAction {
        public ActionAfficherDiaporama() {
            super("Diaporama");
            putValue(Action.ACCELERATOR_KEY,KeyStroke.getKeyStroke(KeyEvent.VK_D, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY,KeyEvent.VK_D);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            diaporama.setVisible(true);
            enableDiaporama(false);
        }
    }

    private class ActionAfficherTexte extends AbstractAction {
        public ActionAfficherTexte() {
            super("Saisie de texte");
            putValue(Action.ACCELERATOR_KEY,KeyStroke.getKeyStroke(KeyEvent.VK_T, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY,KeyEvent.VK_T);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            texte.setVisible(true);
            enableTexte(false);
        }
    }
    
    public class ActionAfficherConversion extends AbstractAction {
        public ActionAfficherConversion() {
            super("Conversion Celsius/Farenheit");
            putValue(Action.ACCELERATOR_KEY,KeyStroke.getKeyStroke(KeyEvent.VK_C, InputEvent.CTRL_DOWN_MASK));
            putValue(Action.MNEMONIC_KEY,KeyEvent.VK_C);
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            conversion.setVisible(true);
            enableConversion(false);
        }
    }

    public void enableConversion(boolean b) {
        actionAfficherConversion.setEnabled(b);
    }

    public void enableTexte(boolean b) {
        actionAfficherTexte.setEnabled(b);
    }

    public void enableDiaporama(boolean b) {
        actionAfficherDiaporama.setEnabled(b);
    }

    public void enableBoutons(boolean b) {
        actionAfficherBoutons.setEnabled(b);
    }

    public Action getActionAfficherConversion() {
        return actionAfficherConversion;
    }

    public Action getActionAfficherTexte() {
        return actionAfficherTexte;
    }

    public Action getActionAfficherDiaporama() {
        return actionAfficherDiaporama;
    }

    public Action getActionAfficherBoutons() {
        return actionAfficherBoutons;
    }

    public void enableCommentFaire(boolean b) {
        actionAfficherCommentFaire.setEnabled(b);
    }

    public Action getActionCommentFaire() {
        return actionAfficherCommentFaire;
    }

    public void enableConfigurationMenu(boolean b) {
        actionAfficherConfigurationMenu.setEnabled(b);
    }

    public static void main(String[] args) {
        try {
            Properties p = System.getProperties();            
            String name = p.getProperty("user.name");
            
            String chemin = "src/main/java/edu/mermet/tp8/donnees/"+ name +".properties";
            File compFile = new File(chemin);
            
            if(!compFile.isFile()) {
                OutputStream compOut = new FileOutputStream(chemin);
                
                Properties properties = new Properties();
                properties.setProperty("competence", "1");
                properties.setProperty("conversion", "Auto");
                properties.setProperty("texte", "Auto");
                properties.setProperty("diaporama", "Auto");
                properties.setProperty("boutons", "Auto");
                
                properties.setProperty("1", "<html>Dans Aide, vous pourrez trouver l'item Comment Faire ?.<br>Comment Faire ? permet d'ouvrir la fenetre d'aide.</html>");
                properties.setProperty("2", "Faites Ctrl+M pour ouvrir la fenêtre de Comment Faire ?");
                properties.setProperty("3", "<html>Dans Aide, vous pourrez trouver l'item Configuration.<br>Configuration permet d'ouvrir la fenetre pour configurer l'affichage des autres fenêtres.</html>");
                properties.setProperty("4", "Faites Ctrl+O pour ouvrir la fenêtre de Configuration");
                properties.setProperty("5", "<html>Dans Applications, vous pourrez trouver l'item Boutons.<br>Boutons permet d'ouvrir la fenetre avec des boutons,<br>  pour ouvrir les fenêtres Conversion, Saisie de Texte et Diaporama.</html>");
                properties.setProperty("6", "Faites Ctrl+B pour ouvrir la fenêtre de Boutons");
                properties.setProperty("7", "<html>Dans Fichier, vous pourrez trouver l'item Quitter.<br>Quitter permet de fermer l'application.</html>");
                properties.setProperty("8", "Faites Ctrl+Q pour quitter l'application"); 
                properties.setProperty("9", "<html>Dans Applications, vous pourrez trouver l'item Diaporama.<br>Diaporama permet d'ouvrir la fenêtre avec un diaporama.</html>");
                properties.setProperty("10", "Faites Ctrl+D pour ouvrir la fenêtre de Diaporama");
                properties.setProperty("11", "<html>Dans Applications, vous pourrez trouver l'item Conversion.<br>Conversion permet d'ouvrir la fenetre pour convertir des valeurs en Celsius en Farenheit et inversement.</html>");
                properties.setProperty("12", "Faites Ctrl+C pour ouvrir la fenêtre de Conversion");
                properties.setProperty("13", "<html>Dans Applications, vous pourrez trouver l'item Saisie de Texte.<br>Saisie de Texte permet d'ouvrir la fenetre pour saisir du texte.</html>");
                properties.setProperty("14", "Faites Ctrl+T pour ouvrir la fenêtre de Saisie de Texte");
                
                for(int i = 1; i <= 14; i++) {
                    if(i <= 6 ) {
                        properties.setProperty("sug"+i, "yes");
                    }else {
                        properties.setProperty("sug"+i, "cach");
                    }                    
                }
                
                properties.store(compOut, null);
            }
        } catch (IOException io) {
            io.printStackTrace();
        }

        SwingUtilities.invokeLater(Application::new);
    }

    
}
